@@ -7,6 +7,8 @@ from jinjafy import jinjafy_comment
 from bs4 import BeautifulSoup
 import glob
 from jinjafy import execute_command
+import zipfile
+import tempfile
 
 CDIR = os.path.dirname(os.path.realpath(__file__))
 CDIR = CDIR.replace('\\','/')
@@ -407,6 +409,34 @@ def move_template_files(output_dir="examples/output", output_tex_file=None):
                      "02450_beamer_preamble.tex",  # Deprecated.
                      'beamer_slider_preamble.tex', # The current version.
                      ]
+
+    zipf = DTU_beamer_base + "/DTU_Beamer_files.zip"
+    # os.path.exists(zipf)
+
+    tmp = tempfile.mkdtemp()
+
+    # output_dir = output_dir)
+    # import random
+    # "".join( [str(random.randint(1, 10))  for _ in range(10)] )
+    # tmp = str(output_dir) +   "/"+  "".join( [str(random.randint(1, 10))  for _ in range(10)] )
+    # os.mkdir(tmp)
+
+    with zipfile.ZipFile(zipf) as zip:
+        # for files in zip.namelist():
+        #     data = zip.read(files, output_dir)
+        #     myfile_path = output_dir / Path(files).name
+        #     myfile_path.write_bytes(data)
+        # zip.extract(name, output_dir +"/" + os.path.basename(name))
+        zip.extractall(tmp)
+
+    for f in glob.glob(tmp + "/**/*.*"):
+        shutil.move(f, str(output_dir) + "/"+os.path.basename(f))
+    shutil.rmtree(tmp)
+    if output_tex_file != None:
+        assert False
+    return
+    print(f)
+
     sd = list( zip(files_to_move, files_to_move) )
     if output_tex_file:
         sd.append( ("02450_lectures_base.tex", output_tex_file))
