@@ -122,9 +122,8 @@ def set_svg_background_images(lecture_tex, verbose=False,
 
         from slider import latexmk
         print("Compiling latex file using latexmk...", os.path.basename(lecture_tex_nosvg))
-        latexmk(os.path.basename(lecture_tex_nosvg))
-
-        execute_command(("latexmk -shell-escape -f -pdf -interaction=nonstopmode " + os.path.basename(lecture_tex_nosvg)).split(" "))
+        latexmk(os.path.abspath(lecture_tex_nosvg))
+        # execute_command(("latexmk -shell-escape -f -pdf -interaction=nonstopmode " + os.path.basename(lecture_tex_nosvg)).split(" "))
         os.chdir(cdir)
         cache_update_file(MAIN_TEX_DIR, lecture_tex_nosvg)
         ANY_CHANGES = True
